package
Version:
v0.0.0-...-18354f7
Opens a new window with list of versions in this module.
Published: Aug 25, 2023
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type NotificationResource struct {
ID uint `json:"id"`
User UserResource `json:"user"`
FollowId uint `json:"follow_id"`
Type string `json:"type"`
Message string `json:"message"`
CreatedAt time.Time `json:"created_at"`
}
type PostResource struct {
UUID string `json:"uuid"`
Author UserResource `json:"author"`
Content string `json:"content"`
Media string `json:"media"`
CreatedAt time.Time `json:"created_at"`
Likes uint `json:"likes"`
Liked bool `json:"liked"`
}
type ProfileResource struct {
UUID string `json:"uuid"`
Name string `json:"name"`
Username string `json:"username"`
Link string `json:"link"`
Bio string `json:"bio"`
Birthday *time.Time `json:"birthday"`
Image string `json:"image"`
IsPrivate bool `json:"is_private"`
}
type UserResource struct {
UUID string `json:"uuid"`
Name string `json:"name"`
Username string `json:"username"`
Image string `json:"image"`
IsPrivate bool `json:"is_private"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.